@@ -8,11 +8,14 @@ from .log import logger
 
 @asyncio.coroutine
 def create_pool(dsn=None, *, minsize=10, maxsize=10,
-                loop=None, timeout=TIMEOUT, enable_json=True, **kwargs):
+                loop=None, timeout=TIMEOUT,
+                enable_json=True, enable_hstore=True,
+                **kwargs):
     if loop is None:
         loop = asyncio.get_event_loop()
 
-    pool = Pool(dsn, minsize, maxsize, loop, timeout, enable_json=enable_json,
+    pool = Pool(dsn, minsize, maxsize, loop, timeout,
+                enable_json=enable_json, enable_hstore=enable_hstore,
                 **kwargs)
     yield from pool._fill_free_pool(False)
     return pool
@@ -22,7 +25,7 @@ class Pool:
     """Connection pool"""
 
     def __init__(self, dsn, minsize, maxsize, loop, timeout, *,
-                 enable_json, **kwargs):
+                 enable_json, enable_hstore, **kwargs):
         if minsize < 0:
             raise ValueError("minsize should be zero or greater")
         if maxsize < minsize:
@@ -32,6 +35,7 @@ class Pool:
         self._loop = loop
         self._timeout = timeout
         self._enable_json = enable_json
+        self._enable_hstore = enable_hstore
         self._conn_kwargs = kwargs
         self._free = asyncio.queues.Queue(maxsize, loop=self._loop)
         self._used = set()
@@ -79,6 +83,7 @@ class Pool:
             conn = yield from connect(
                 self._dsn, loop=self._loop, timeout=self._timeout,
                 enable_json=self._enable_json,
+                enable_hstore=self._enable_hstore,
                 **self._conn_kwargs)
             yield from self._free.put(conn)
         if not self._free.empty():
@@ -87,6 +92,7 @@ class Pool:
             conn = yield from connect(
                 self._dsn, loop=self._loop, timeout=self._timeout,
                 enable_json=self._enable_json,
+                enable_hstore=self._enable_hstore,
                 **self._conn_kwargs)
             yield from self._free.put(conn)
 
